"""
Defines the base PSQL class used for all Postgres based statments.
"""

# define authorship information
__authors__         = ['Eric Hulser']
__author__          = ','.join(__authors__)
__credits__         = []
__copyright__       = 'Copyright (c) 2011, Projex Software'
__license__         = 'LGPL'

# maintanence information
__maintainer__      = 'Projex Software'
__email__           = 'team@projexsoftware.com'

import orb
from ..abstractsql import SQL
from .statements import __plugins__

class PSQL(SQL):
    @classmethod
    def createDatastore(cls):
        """
        Returns the PSQL data store class.
        
        :return     subclass of <orb.DataStore>
        """
        store_type = orb.DataStore.byName('Postgres', orb.DataStore)
        return store_type()

# load the SQL plugins for PostgreSQL
PSQL.loadStatements(__plugins__)

#----------------------------------------------------------------------

# define custom column types for PostgreSQL
PSQL.registerAddon('Type::Bool',                    'BOOLEAN')
PSQL.registerAddon('Type::BigInt',                  'BIGINT')
PSQL.registerAddon('Type::ByteArray',               'BYTEA')
PSQL.registerAddon('Type::Color',                   'CHARACTER VARYING')
PSQL.registerAddon('Type::Datetime',                'TIMESTAMP WITHOUT TIME ZONE')
PSQL.registerAddon('Type::DatetimeWithTimezone',    'TIMESTAMP WITHOUT TIME ZONE')
PSQL.registerAddon('Type::Decimal',                 'DECIMAL')
PSQL.registerAddon('Type::Dict',                    'BYTEA')
PSQL.registerAddon('Type::Directory',               'CHARACTER VARYING')
PSQL.registerAddon('Type::Double',                  'DOUBLE PRECISION')
PSQL.registerAddon('Type::Email',                   'CHARACTER VARYING')
PSQL.registerAddon('Type::Enum',                    'INTEGER')
PSQL.registerAddon('Type::Filepath',                'CHARACTER VARYING')
PSQL.registerAddon('Type::ForeignKey',              'BIGINT')
PSQL.registerAddon('Type::Image',                   'BYTEA')
PSQL.registerAddon('Type::Integer',                 'INTEGER')
PSQL.registerAddon('Type::Interval',                'TIMEDELTA')
PSQL.registerAddon('Type::Password',                'CHARACTER VARYING')
PSQL.registerAddon('Type::Pickle',                  'BYTEA')
PSQL.registerAddon('Type::String',                  'CHARACTER VARYING')
PSQL.registerAddon('Type::Url',                     'CHARACTER VARYING')

# register the PSQLStatement addon interface to the base SQLStatement class
SQL.registerAddon('Postgres', PSQL)

# register the statements addons for PSQL
from .statements import __plugins__
PSQL.registerAddonModule(__plugins__)

